@@ -1,4 +1,5 @@
 /* application object */
+/* vim: set sw=2 et: */
 
 /*
  * Copyright (C) 2001 Havoc Pennington
@@ -26,6 +27,26 @@
 #include "application.h"
 #include "private.h"
 
+/**
+ * SECTION:application
+ * @short_description: an object representing a group of windows of the same
+ * application.
+ * @see_also: wnck_window_get_application()
+ * @stability: Unstable
+ *
+ * The #WnckApplication is a group of #WnckWindow that are all in the same
+ * application. It can be used to represent windows by applications, group
+ * windows by applications or to manipulate all windows of a particular
+ * application.
+ *
+ * A #WnckApplication is identified by the group leader of the #WnckWindow
+ * belonging to it, and new #WnckWindow are added to a #WnckApplication if and
+ * only if they have the group leader of the #WnckApplication.
+ *
+ * The #WnckApplication objects are always owned by libwnck and must not be
+ * referenced or unreferenced.
+ */
+
 #define FALLBACK_NAME _("Untitled application")
 
 static GHashTable *app_hash = NULL;
@@ -55,6 +76,8 @@ struct _WnckApplicationPrivate
   guint need_emit_icon_changed : 1;
 };
 
+G_DEFINE_TYPE (WnckApplication, wnck_application, G_TYPE_OBJECT);
+
 enum {
   NAME_CHANGED,
   ICON_CHANGED,
@@ -72,40 +95,8 @@ static void wnck_application_class_init  (WnckApplicationClass *klass);
 static void wnck_application_finalize    (GObject        *object);
 
 
-static gpointer parent_class;
 static guint signals[LAST_SIGNAL] = { 0 };
 
-GType
-wnck_application_get_type (void)
-{
-  static GType object_type = 0;
-
-  g_type_init ();
-  
-  if (!object_type)
-    {
-      const GTypeInfo object_info =
-      {
-        sizeof (WnckApplicationClass),
-        (GBaseInitFunc) NULL,
-        (GBaseFinalizeFunc) NULL,
-        (GClassInitFunc) wnck_application_class_init,
-        NULL,           /* class_finalize */
-        NULL,           /* class_data */
-        sizeof (WnckApplication),
-        0,              /* n_preallocs */
-        (GInstanceInitFunc) wnck_application_init,
-        NULL            /* value_table */
-      };
-      
-      object_type = g_type_register_static (G_TYPE_OBJECT,
-                                            "WnckApplication",
-                                            &object_info, 0);
-    }
-  
-  return object_type;
-}
-
 static void
 wnck_application_init (WnckApplication *application)
 {  
@@ -121,10 +112,14 @@ wnck_application_class_init (WnckApplicationClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   
-  parent_class = g_type_class_peek_parent (klass);
-
   object_class->finalize = wnck_application_finalize;
   
+  /**
+   * WnckApplication::name-changed:
+   * @app: the #WnckApplication which emitted the signal.
+   *
+   * Emitted when the name of @app changes.
+   */
   signals[NAME_CHANGED] =
     g_signal_new ("name_changed",
                   G_OBJECT_CLASS_TYPE (object_class),
@@ -134,6 +129,12 @@ wnck_application_class_init (WnckApplicationClass *klass)
                   g_cclosure_marshal_VOID__VOID,
                   G_TYPE_NONE, 0);
 
+  /**
+   * WnckApplication::icon-changed:
+   * @app: the #WnckApplication which emitted the signal.
+   *
+   * Emitted when the icon of @app changes.
+   */
   signals[ICON_CHANGED] =
     g_signal_new ("icon_changed",
                   G_OBJECT_CLASS_TYPE (object_class),
@@ -163,9 +164,20 @@ wnck_application_finalize (GObject *object)
   
   g_free (application->priv);
   
-  G_OBJECT_CLASS (parent_class)->finalize (object);
+  G_OBJECT_CLASS (wnck_application_parent_class)->finalize (object);
 }
 
+/**
+ * wnck_application_get:
+ * @xwindow: the X window ID of a group leader.
+ *
+ * Returns the #WnckApplication corresponding to the group leader with @xwindow
+ * as X window ID.
+ *
+ * Return value: the #WnckApplication corresponding to @xwindow, or %NULL if
+ * there no such #WnckApplication could be found. The returned #WnckApplication
+ * is owned by libwnck and must not be referenced or unreferenced.
+ */
 WnckApplication*
 wnck_application_get (gulong xwindow)
 {
@@ -177,11 +189,11 @@ wnck_application_get (gulong xwindow)
 
 /**
  * wnck_application_get_xid:
- * @app: a #WnckApplication
+ * @app: a #WnckApplication.
  * 
- * Gets the X id of the group leader window for the app.
+ * Returns the X window ID of the group leader window for @app.
  * 
- * Return value: X id for the app
+ * Return value: the X window ID of the group leader window for @app.
  **/
 gulong
 wnck_application_get_xid (WnckApplication *app)
@@ -193,12 +205,13 @@ wnck_application_get_xid (WnckApplication *app)
 
 /**
  * wnck_application_get_windows:
- * @app: a #WnckApplication
+ * @app: a #WnckApplication.
  * 
- * Gets a list of all windows belonging to @app. The list
- * is returned by reference and should not be freed.
+ * Returns the list of #WnckWindow belonging to @app.
  * 
- * Return value: list of #WnckWindow in this app
+ * Return value: the list of #WnckWindow belonging to @app, or %NULL if the
+ * application contains no window. The list should not be modified nor freed,
+ * as it is owned by @app.
  **/
 GList*
 wnck_application_get_windows (WnckApplication *app)
@@ -208,6 +221,14 @@ wnck_application_get_windows (WnckApplication *app)
   return app->priv->windows;
 }
 
+/**
+ * wnck_application_get_n_windows:
+ * @app: a #WnckApplication.
+ * 
+ * Returns the number of #WnckWindow belonging to @app.
+ * 
+ * Return value: the number of #WnckWindow belonging to @app.
+ **/
 int
 wnck_application_get_n_windows (WnckApplication *app)
 {
@@ -218,16 +239,16 @@ wnck_application_get_n_windows (WnckApplication *app)
 
 /**
  * wnck_application_get_name:
- * @app: a #WnckApplication
+ * @app: a #WnckApplication.
  * 
- * Gets the name of an application, employing various
- * suboptimal heuristics to try to figure it out.
- * Probably GTK should have a function to allow apps to
- * set _NET_WM_NAME on the group leader as the app name,
- * and the WM spec should say that's where the app name
- * goes.
+ * Returns the name of @app. Since there is no way to properly find this name,
+ * various suboptimal heuristics are used to find it. GTK+ should probably have
+ * a function to allow applications to set the _NET_WM_NAME property on the
+ * group leader as the application name, and the <ulink
+ * url="http://standards.freedesktop.org/wm-spec/wm-spec-latest.html">EWMH</ulink>
+ * should say that this is where the application name goes.
  * 
- * Return value: name of the application
+ * Return value: the name of @app, or a fallback name if no name is available.
  **/
 const char*
 wnck_application_get_name (WnckApplication *app)
@@ -244,10 +265,12 @@ wnck_application_get_name (WnckApplication *app)
  * wnck_application_get_icon_name:
  * @app: a #WnckApplication
  * 
- * Gets the icon name of an application, employing various
- * suboptimal heuristics to try to figure it out.
+ * Returns the icon name of @app (to be used when @app is minimized). Since
+ * there is no way to properly find this name, various suboptimal heuristics
+ * are used to find it.
  * 
- * Return value: name of the application when minimized
+ * Return value: the icon name of @app, or a fallback icon name if no icon name
+ * is available.
  **/
 const char*
 wnck_application_get_icon_name (WnckApplication *app)
@@ -266,12 +289,11 @@ wnck_application_get_icon_name (WnckApplication *app)
 
 /**
  * wnck_application_get_pid:
- * @app: a #WnckApplication
+ * @app: a #WnckApplication.
  * 
- * Gets the process ID of an application, or 0 if none
- * is available.
+ * Returns the process ID of @app.
  * 
- * Return value: process ID or 0
+ * Return value: the process ID of @app, or 0 if none is available.
  **/
 int
 wnck_application_get_pid (WnckApplication *app)
@@ -344,9 +366,22 @@ find_icon_window (WnckApplication *app)
     return NULL;
 }
 
+/**
+ * wnck_application_get_icon:
+ * @app: a #WnckApplication.
+ * 
+ * Returns the icon to be used for @app. Since there is no way to
+ * properly find the icon, a suboptimal heuristic is used to find it. If
+ * no icon was found, a fallback icon is used.
+ * 
+ * Return value: the icon for @app. The caller should reference the returned
+ * <classname>GdkPixbuf</classname> if it needs to keep the icon around.
+ **/
 GdkPixbuf*
 wnck_application_get_icon (WnckApplication *app)
 {
+  g_return_val_if_fail (WNCK_IS_APPLICATION (app), NULL);
+
   get_icons (app);
   if (app->priv->need_emit_icon_changed)
     emit_icon_changed (app);
@@ -363,9 +398,23 @@ wnck_application_get_icon (WnckApplication *app)
     }
 }
 
+/**
+ * wnck_application_get_mini_icon:
+ * @app: a #WnckApplication.
+ * 
+ * Returns the mini-icon to be used for @app. Since there is no way to
+ * properly find the mini-icon, a suboptimal heuristic is used to find it. If
+ * no mini-icon was found, a fallback mini-icon is used.
+ * 
+ * Return value: the mini-icon for @app. The caller should reference the
+ * returned <classname>GdkPixbuf</classname> if it needs to keep the mini-icon
+ * around.
+ **/
 GdkPixbuf*
 wnck_application_get_mini_icon (WnckApplication *app)
 {
+  g_return_val_if_fail (WNCK_IS_APPLICATION (app), NULL);
+
   get_icons (app);
   if (app->priv->need_emit_icon_changed)
     emit_icon_changed (app);
@@ -386,10 +435,10 @@ wnck_application_get_mini_icon (WnckApplication *app)
  * wnck_application_get_icon_is_fallback:
  * @app: a #WnckApplication
  *
- * Checks if we are using a default fallback icon because
- * none was set on the application.
+ * Returns whether a default fallback icon is used for @app (because none
+ * was set on @app).
  * 
- * Return value: %TRUE if icon is a fallback
+ * Return value: %TRUE if the icon for @app is a fallback, %FALSE otherwise.
  **/
 gboolean
 wnck_application_get_icon_is_fallback (WnckApplication *app)
@@ -399,6 +448,17 @@ wnck_application_get_icon_is_fallback (WnckApplication *app)
   return _wnck_icon_cache_get_is_fallback (app->priv->icon_cache);
 }
 
+/**
+ * wnck_application_get_startup_id:
+ * @app: a #WnckApplication.
+ *
+ * Returns the startup sequence ID used for startup notification of @app.
+ *
+ * Return value: the startup sequence ID used for startup notification of @app,
+ * or %NULL if none is available.
+ *
+ * Since: 2.2
+ */
 const char*
 wnck_application_get_startup_id (WnckApplication *app)
 {
