@@ -1,4 +1,5 @@
 /* Private stuff */
+/* vim: set sw=2 et: */
 
 /*
  * Copyright (C) 2001 Havoc Pennington
@@ -103,7 +104,6 @@ void _wnck_init (void);
 #define WNCK_SCREEN_XSCREEN(screen) (_wnck_screen_get_xscreen (screen))
 
 Screen    *_wnck_screen_get_xscreen    (WnckScreen *screen);
-int        _wnck_screen_get_number     (WnckScreen *screen);
 GdkScreen *_wnck_screen_get_gdk_screen (WnckScreen *screen);
 
 #ifdef HAVE_STARTUP_NOTIFICATION
@@ -126,6 +126,7 @@ void           _wnck_pager_get_workspace_rect   (WnckPager     *pager,
 
 void           _make_gtk_label_bold   (GtkLabel *label);
 void           _make_gtk_label_normal (GtkLabel *label);
+void           _wnck_stock_icons_init (void);
 
 
 G_END_DECLS
