@@ -1,3 +1,5 @@
+/* selector */
+/* vim: set sw=2 et: */
 /*
  * Copyright (C) 2003 Sun Microsystems, Inc.
  * Copyright (C) 2001 Free Software Foundation, Inc.
@@ -35,6 +37,21 @@
 #include "screen.h"
 #include "private.h"
 
+/**
+ * SECTION:selector
+ * @short_description: a window selector widget, showing the list of windows as
+ * a menu.
+ * @see_also: #WnckTasklist
+ * @stability: Unstable
+ *
+ * The #WnckSelector represents client windows on a screen as a menu, where
+ * menu items are labelled with the window titles and icons. Activating a menu
+ * item activates the represented window.
+ *
+ * The #WnckSelector will automatically detect the screen it is on, and will
+ * represent windows of this screen only.
+ */
+
 typedef struct
 {
   GtkWidget *item;
@@ -57,6 +74,9 @@ struct _WnckSelectorPrivate {
 
 G_DEFINE_TYPE (WnckSelector, wnck_selector, GTK_TYPE_MENU_BAR);
 
+static GObject *wnck_selector_constructor (GType                  type,
+                                           guint                  n_construct_properties,
+                                           GObjectConstructParam *construct_properties);
 static void wnck_selector_finalize          (GObject           *object);
 static void wnck_selector_realize           (GtkWidget *widget);
 static void wnck_selector_unrealize         (GtkWidget *widget);
@@ -552,7 +572,19 @@ wnck_selector_drag_begin (GtkWidget          *widget,
 			  GdkDragContext     *context,
 			  WnckWindow         *window)
 {
-  _wnck_window_set_as_drag_icon (window, context, widget);
+  while (widget)
+    {
+      if (WNCK_IS_SELECTOR (widget))
+        break;
+
+      if (GTK_IS_MENU (widget))
+        widget = gtk_menu_get_attach_widget (GTK_MENU (widget));
+      else
+        widget = widget->parent;
+    }
+
+  if (widget)
+    _wnck_window_set_as_drag_icon (window, context, widget);
 }
 
 static void  
@@ -1242,6 +1274,7 @@ wnck_selector_class_init (WnckSelectorClass *klass)
   GtkObjectClass *gtk_object_class = GTK_OBJECT_CLASS (klass);
   GtkWidgetClass *widget_class     = GTK_WIDGET_CLASS (klass);
 
+  object_class->constructor = wnck_selector_constructor;
   object_class->finalize = wnck_selector_finalize;
 
   gtk_object_class->destroy = wnck_selector_destroy;
@@ -1252,6 +1285,23 @@ wnck_selector_class_init (WnckSelectorClass *klass)
   g_type_class_add_private (klass, sizeof (WnckSelectorPrivate));
 }
 
+static GObject *
+wnck_selector_constructor (GType                  type,
+                           guint                  n_construct_properties,
+                           GObjectConstructParam *construct_properties)
+{
+  GObject *obj;
+
+  obj = G_OBJECT_CLASS (wnck_selector_parent_class)->constructor (
+                                                      type,
+                                                      n_construct_properties,
+                                                      construct_properties);
+
+  wnck_selector_fill (WNCK_SELECTOR (obj));
+
+  return obj;
+}
+
 static void
 wnck_selector_finalize (GObject *object)
 {
@@ -1323,6 +1373,16 @@ wnck_selector_unrealize (GtkWidget *widget)
   GTK_WIDGET_CLASS (wnck_selector_parent_class)->unrealize (widget);
 }
 
+/**
+ * wnck_selector_new:
+ *
+ * Creates a new #WnckSelector. The #WnckSelector will list #WnckWindow of the
+ * #WnckScreen it is on.
+ *
+ * Return value: a newly created #WnckSelector.
+ *
+ * Since: 2.10
+ */
 GtkWidget *
 wnck_selector_new (void)
 {
@@ -1330,7 +1390,5 @@ wnck_selector_new (void)
 
   selector = g_object_new (WNCK_TYPE_SELECTOR, NULL);
 
-  wnck_selector_fill (selector);
-
   return GTK_WIDGET (selector);
 }
