@@ -1,4 +1,5 @@
 /* selector */
+/* vim: set sw=2 et: */
 
 /*
  * Copyright (C) 2001 Havoc Pennington
@@ -35,6 +36,12 @@ typedef struct _WnckSelector WnckSelector;
 typedef struct _WnckSelectorClass WnckSelectorClass;
 typedef struct _WnckSelectorPrivate WnckSelectorPrivate;
 
+/**
+ * WnckSelector:
+ *
+ * The #WnckSelector struct contains only private fields and should not be
+ * directly accessed.
+ */
 struct _WnckSelector
 {
   GtkMenuBar parent_instance;
@@ -44,6 +51,12 @@ struct _WnckSelector
 struct _WnckSelectorClass 
 {
   GtkMenuBarClass parent_class;
+  
+  /* Padding for future expansion */
+  void (* pad1) (void);
+  void (* pad2) (void);
+  void (* pad3) (void);
+  void (* pad4) (void);
 };
 
 GtkWidget *wnck_selector_new      (void);
