@@ -1,21 +1,29 @@
+/* vim: set sw=2 et: */
+
 #include <libwnck/libwnck.h>
 #include <gtk/gtk.h>
 
 #include <glib/gi18n.h>
 
 static gboolean display_all = FALSE;
+static gboolean never_group = FALSE;
 static gboolean always_group = FALSE;
+static gboolean rtl = FALSE;
+static gboolean skip_tasklist = FALSE;
 
 static GOptionEntry entries[] = {
-	{"always-group", 'a', 0, G_OPTION_ARG_NONE, &always_group, N_("Always group windows"), NULL},
+	{"always-group", 'g', 0, G_OPTION_ARG_NONE, &always_group, N_("Always group windows"), NULL},
+	{"never-group", 'n', 0, G_OPTION_ARG_NONE, &never_group, N_("Never group windows"), NULL},
 	{"display-all", 'a', 0, G_OPTION_ARG_NONE, &display_all, N_("Display windows from all workspaces"), NULL},
+	{"rtl", 'r', 0, G_OPTION_ARG_NONE, &rtl, N_("Use RTL as default direction"), NULL},
+	{"skip-tasklist", 's', 0, G_OPTION_ARG_NONE, &skip_tasklist, N_("Don't show window in tasklist"), NULL},
 	{NULL }
 };
 
 int
 main (int argc, char **argv)
 {
-  GOptionContext* ctxt;
+  GOptionContext *ctxt;
   WnckScreen *screen;
   GtkWidget *win;
   GtkWidget *frame;
@@ -28,8 +36,9 @@ main (int argc, char **argv)
   g_option_context_free (ctxt);
   ctxt = NULL;
 
-  /* to test rtl layout, set RTL=1 in the environment */
-  if (g_getenv ("RTL"))
+  gtk_init (&argc, &argv);
+
+  if (rtl)
     gtk_widget_set_default_direction (GTK_TEXT_DIR_RTL);
 
   screen = wnck_screen_get_default ();
@@ -56,6 +65,9 @@ main (int argc, char **argv)
   if (always_group)
     wnck_tasklist_set_grouping (WNCK_TASKLIST (tasklist),
                                 WNCK_TASKLIST_ALWAYS_GROUP);
+  else if (never_group)
+    wnck_tasklist_set_grouping (WNCK_TASKLIST (tasklist),
+                                WNCK_TASKLIST_NEVER_GROUP);
   else
     wnck_tasklist_set_grouping (WNCK_TASKLIST (tasklist),
                                 WNCK_TASKLIST_AUTO_GROUP);
@@ -71,6 +83,12 @@ main (int argc, char **argv)
 
   gtk_window_move (GTK_WINDOW (win), 0, 0);
   
+  if (skip_tasklist)
+  {
+    gtk_window_set_skip_taskbar_hint (GTK_WINDOW (win), TRUE); 
+    gtk_window_set_keep_above (GTK_WINDOW (win), TRUE); 
+  }
+
   gtk_widget_show (win);
   
   gtk_main ();
