@@ -1,4 +1,5 @@
 /* window action menu (ops on a single window) */
+/* vim: set sw=2 et: */
 
 /*
  * Copyright (C) 2001 Havoc Pennington
@@ -28,6 +29,17 @@
 #include "window-action-menu.h"
 #include "private.h"
 
+/**
+ * SECTION:window-action-menu
+ * @short_description: context menu used to manipulate a window.
+ * @see_also: #WnckWindow
+ * @stability: Unstable
+ *
+ * These functions are related to the context menu that is usually used to
+ * manipulate a window (closing it, minimizing it, maximizing it, moving it to
+ * another workspace, etc.).
+ */
+
 typedef enum
 {
   CLOSE,
@@ -551,11 +563,12 @@ get_workspace_name_with_accel (WnckWindow *window,
 
 /**
  * wnck_create_window_action_menu:
- * @window: a #WnckWindow
+ * @window: the #WnckWindow for which a menu will be created.
  * 
  * Creates a menu of window operations for @window.
  * 
- * Return value: a new menu of window operations
+ * Return value: a new GtkMenu, filled with menu items for window operations on
+ * @window.
  **/
 GtkWidget*
 wnck_create_window_action_menu (WnckWindow *window)
@@ -563,11 +576,13 @@ wnck_create_window_action_menu (WnckWindow *window)
   GtkWidget *menu, *submenu;
   ActionMenuData *amd;
   GtkWidget *separator;
-  int num_workspaces, present_workspace, i;
+  int num_workspaces, window_space, i;
   WnckWorkspace *workspace;
   WnckWorkspaceLayout layout;
   GSList *pin_group;
 
+  g_return_val_if_fail (WNCK_IS_WINDOW (window), NULL);
+
   _wnck_stock_icons_init ();
   
   amd = g_new0 (ActionMenuData, 1);
@@ -637,13 +652,13 @@ wnck_create_window_action_menu (WnckWindow *window)
   num_workspaces = wnck_screen_get_workspace_count (wnck_window_get_screen (amd->window));
 
   if (workspace)
-    present_workspace = wnck_workspace_get_number (workspace);
+    window_space = wnck_workspace_get_number (workspace);
   else
-    present_workspace = -1;
+    window_space = -1; //FIXME: this probably causes weird results. How to verify?
 
   wnck_screen_calc_workspace_layout (wnck_window_get_screen (amd->window),
                                      num_workspaces,
-                                     present_workspace,
+                                     window_space,
                                      &layout);
 
   if (!wnck_window_is_pinned (amd->window))
@@ -715,7 +730,7 @@ wnck_create_window_action_menu (WnckWindow *window)
       item = make_menu_item (amd, MOVE_TO_WORKSPACE);
       g_object_set_data (G_OBJECT (item), "workspace", GINT_TO_POINTER (i));
 
-      if (i == present_workspace)
+      if (i == window_space)
         gtk_widget_set_sensitive (item, FALSE);
 
       gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
